ZegoUIKitBeautyPlugin class
Constructors
- ZegoUIKitBeautyPlugin()
-
factory
Properties
- core ↔ ZegoUIKitBeautyCore
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getErrorStream(
) → Stream< ZegoBeautyError> - get Error Stream
-
getFaceDetectionEventStream(
) → Stream< ZegoBeautyPluginFaceDetectionData> - get Face Detection Event Stream
-
getPlatformVersion(
) → Future< String?> -
getPluginType(
) → ZegoUIKitPluginType - getPluginType
-
getVersion(
) → Future< String> - getVersion
-
init(
{required int appID, required String appSign}) → Future< void> - init
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAdvancedConfig(
String key, String value) → Future< void> -
setBeautyParams(
List< ZegoBeautyParamConfig> paramConfigList, {bool forceUpdateCache = false}) → Future<void> - Set default beauty parameters
-
setConfig(
ZegoBeautyPluginConfig config) → void - set Config
-
showBeautyUI(
BuildContext context) → void - show Beauty UI
-
toString(
) → String -
A string representation of this object.
inherited
-
uninit(
) → void - uninit
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → ZegoUIKitBeautyPlugin
-
final